==> arvados-node-manager-0.1.20170809191140.tar.gz: arvados-node-manager-0.1.20170809191140/arvnodeman/computenode/dispatch/transitions.py <==
# Copyright (C) The Arvados Authors. All rights reserved.
#
# SPDX-License-Identifier: AGPL-3.0

transitions = {
 ('busy', 'closed', 'boot exceeded', 'idle exceeded'): None,
 ('busy', 'closed', 'boot exceeded', 'idle wait'): None,
 ('busy', 'closed', 'boot exceeded', 'not idle'): None,
 ('busy', 'closed', 'boot wait', 'idle exceeded'): None,
 ('busy', 'closed', 'boot wait', 'idle wait'): None,
 ('busy', 'closed', 'boot wait', 'not idle'): None,
 ('busy', 'open', 'boot exceeded', 'idle exceeded'): None,
 ('busy', 'open', 'boot exceeded', 'idle wait'): None,
 ('busy', 'open', 'boot exceeded', 'not idle'): None,
 ('busy', 'open', 'boot wait', 'idle exceeded'): None,
 ('busy', 'open', 'boot wait', 'idle wait'): None,
 ('busy', 'open', 'boot wait', 'not idle'): None,

 ('down', 'closed', 'boot exceeded', 'idle exceeded'): "START_SHUTDOWN",
 ('down', 'closed', 'boot exceeded', 'idle wait'): "START_SHUTDOWN",
 ('down', 'closed', 'boot exceeded', 'not idle'): "START_SHUTDOWN",
 ('down', 'closed', 'boot wait', 'idle exceeded'): None,
 ('down', 'closed', 'boot wait', 'idle wait'): None,
 ('down', 'closed', 'boot wait', 'not idle'): None,
 ('down', 'open', 'boot exceeded', 'idle exceeded'): "START_SHUTDOWN",
 ('down', 'open', 'boot exceeded', 'idle wait'): "START_SHUTDOWN",
 ('down', 'open', 'boot exceeded', 'not idle'): "START_SHUTDOWN",
 ('down', 'open', 'boot wait', 'idle exceeded'): "START_SHUTDOWN",
 ('down', 'open', 'boot wait', 'idle wait'): "START_SHUTDOWN",
 ('down', 'open', 'boot wait', 'not idle'): "START_SHUTDOWN",

 ('idle', 'closed', 'boot exceeded', 'idle exceeded'): None,
 ('idle', 'closed', 'boot exceeded', 'idle wait'): None,
 ('idle', 'closed', 'boot exceeded', 'not idle'): None,
 ('idle', 'closed', 'boot wait', 'idle exceeded'): None,
 ('idle', 'closed', 'boot wait', 'idle wait'): None,
 ('idle', 'closed', 'boot wait', 'not idle'): None,
 ('idle', 'open', 'boot exceeded', 'idle exceeded'): "START_DRAIN",
 ('idle', 'open', 'boot exceeded', 'idle wait'): None,
 ('idle', 'open', 'boot exceeded', 'not idle'): None,
 ('idle', 'open', 'boot wait', 'idle exceeded'): "START_DRAIN",
 ('idle', 'open', 'boot wait', 'idle wait'): None,
 ('idle', 'open', 'boot wait', 'not idle'): None,

 ('unpaired', 'closed', 'boot exceeded', 'idle exceeded'): "START_SHUTDOWN",
 ('unpaired', 'closed', 'boot exceeded', 'idle wait'): "START_SHUTDOWN",
 ('unpaired', 'closed', 'boot exceeded', 'not idle'): "START_SHUTDOWN",
 ('unpaired', 'closed', 'boot wait', 'idle exceeded'): None,
 ('unpaired', 'closed', 'boot wait', 'idle wait'): None,
 ('unpaired', 'closed', 'boot wait', 'not idle'): None,
 ('unpaired', 'open', 'boot exceeded', 'idle exceeded'): "START_SHUTDOWN",
 ('unpaired', 'open', 'boot exceeded', 'idle wait'): "START_SHUTDOWN",
 ('unpaired', 'open', 'boot exceeded', 'not idle'): "START_SHUTDOWN",
 ('unpaired', 'open', 'boot wait', 'idle exceeded'): None,
 ('unpaired', 'open', 'boot wait', 'idle wait'): None,
 ('unpaired', 'open', 'boot wait', 'not idle'): None}

==> arvados-node-manager-1.3.2.20190509143736.tar.gz: arvados-node-manager-1.3.2.20190509143736/arvnodeman/computenode/dispatch/transitions.py <==
# Copyright (C) The Arvados Authors. All rights reserved.
#
# SPDX-License-Identifier: AGPL-3.0

transitions = {
 ('busy', 'closed', 'boot exceeded', 'idle exceeded'): None,
 ('busy', 'closed', 'boot exceeded', 'idle wait'): None,
 ('busy', 'closed', 'boot exceeded', 'not idle'): None,
 ('busy', 'closed', 'boot wait', 'idle exceeded'): None,
 ('busy', 'closed', 'boot wait', 'idle wait'): None,
 ('busy', 'closed', 'boot wait', 'not idle'): None,
 ('busy', 'open', 'boot exceeded', 'idle exceeded'): None,
 ('busy', 'open', 'boot exceeded', 'idle wait'): None,
 ('busy', 'open', 'boot exceeded', 'not idle'): None,
 ('busy', 'open', 'boot wait', 'idle exceeded'): None,
 ('busy', 'open', 'boot wait', 'idle wait'): None,
 ('busy', 'open', 'boot wait', 'not idle'): None,

 ('down', 'closed', 'boot exceeded', 'idle exceeded'): "START_SHUTDOWN",
 ('down', 'closed', 'boot exceeded', 'idle wait'): "START_SHUTDOWN",
 ('down', 'closed', 'boot exceeded', 'not idle'): "START_SHUTDOWN",
 ('down', 'closed', 'boot wait', 'idle exceeded'): None,
 ('down', 'closed', 'boot wait', 'idle wait'): None,
 ('down', 'closed', 'boot wait', 'not idle'): None,
 ('down', 'open', 'boot exceeded', 'idle exceeded'): "START_SHUTDOWN",
 ('down', 'open', 'boot exceeded', 'idle wait'): "START_SHUTDOWN",
 ('down', 'open', 'boot exceeded', 'not idle'): "START_SHUTDOWN",
 ('down', 'open', 'boot wait', 'idle exceeded'): "START_SHUTDOWN",
 ('down', 'open', 'boot wait', 'idle wait'): "START_SHUTDOWN",
 ('down', 'open', 'boot wait', 'not idle'): "START_SHUTDOWN",

 ('idle', 'closed', 'boot exceeded', 'idle exceeded'): None,
 ('idle', 'closed', 'boot exceeded', 'idle wait'): None,
 ('idle', 'closed', 'boot exceeded', 'not idle'): None,
 ('idle', 'closed', 'boot wait', 'idle exceeded'): None,
 ('idle', 'closed', 'boot wait', 'idle wait'): None,
 ('idle', 'closed', 'boot wait', 'not idle'): None,
 ('idle', 'open', 'boot exceeded', 'idle exceeded'): "START_DRAIN",
 ('idle', 'open', 'boot exceeded', 'idle wait'): None,
 ('idle', 'open', 'boot exceeded', 'not idle'): None,
 ('idle', 'open', 'boot wait', 'idle exceeded'): "START_DRAIN",
 ('idle', 'open', 'boot wait', 'idle wait'): None,
 ('idle', 'open', 'boot wait', 'not idle'): None,

 ('unpaired', 'closed', 'boot exceeded', 'idle exceeded'): "START_SHUTDOWN",
 ('unpaired', 'closed', 'boot exceeded', 'idle wait'): "START_SHUTDOWN",
 ('unpaired', 'closed', 'boot exceeded', 'not idle'): "START_SHUTDOWN",
 ('unpaired', 'closed', 'boot wait', 'idle exceeded'): None,
 ('unpaired', 'closed', 'boot wait', 'idle wait'): None,
 ('unpaired', 'closed', 'boot wait', 'not idle'): None,
 ('unpaired', 'open', 'boot exceeded', 'idle exceeded'): "START_SHUTDOWN",
 ('unpaired', 'open', 'boot exceeded', 'idle wait'): "START_SHUTDOWN",
 ('unpaired', 'open', 'boot exceeded', 'not idle'): "START_SHUTDOWN",
 ('unpaired', 'open', 'boot wait', 'idle exceeded'): None,
 ('unpaired', 'open', 'boot wait', 'idle wait'): None,
 ('unpaired', 'open', 'boot wait', 'not idle'): None,

 ('fail', 'closed', 'boot exceeded', 'idle exceeded'): "START_SHUTDOWN",
 ('fail', 'closed', 'boot exceeded', 'idle wait'): "START_SHUTDOWN",
 ('fail', 'closed', 'boot exceeded', 'not idle'): "START_SHUTDOWN",
 ('fail', 'closed', 'boot wait', 'idle exceeded'): "START_SHUTDOWN",
 ('fail', 'closed', 'boot wait', 'idle wait'): "START_SHUTDOWN",
 ('fail', 'closed', 'boot wait', 'not idle'): "START_SHUTDOWN",
 ('fail', 'open', 'boot exceeded', 'idle exceeded'): "START_SHUTDOWN",
 ('fail', 'open', 'boot exceeded', 'idle wait'): "START_SHUTDOWN",
 ('fail', 'open', 'boot exceeded', 'not idle'): "START_SHUTDOWN",
 ('fail', 'open', 'boot wait', 'idle exceeded'): "START_SHUTDOWN",
 ('fail', 'open', 'boot wait', 'idle wait'): "START_SHUTDOWN",
 ('fail', 'open', 'boot wait', 'not idle'): "START_SHUTDOWN"}
